//
//  YHAppleLoginManager.swift
//  galaxy
//
//  Created by edy on 2024/5/29.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import AuthenticationServices

class YHAppleLoginManager: NSObject {
    
    static let shared = YHAppleLoginManager()

    func appleLogin() {
        
        let appleIDProvider = ASAuthorizationAppleIDProvider()
        let request = appleIDProvider.createRequest()
        request.requestedScopes = [.fullName, .email]
        let vc = ASAuthorizationController(authorizationRequests: [request])
        vc.delegate = self
        vc.presentationContextProvider = self
        vc.performRequests()
    }
}

extension YHAppleLoginManager: ASAuthorizationControllerDelegate, ASAuthorizationControllerPresentationContextProviding {
    
    func authorizationController(controller: ASAuthorizationController, didCompleteWithAuthorization authorization: ASAuthorization) {
        
        //  其中`authorization.credential`包含了Token，用户ID等授权所需信息，可上报到后台
        let credential = authorization.credential
        if credential is ASPasswordCredential {
            let passwdCredential = credential as! ASPasswordCredential
            let userIdentifier = passwdCredential.user
            let username = passwdCredential.user
            let password = passwdCredential.password
            printLog("username:\(username), passwd:\(password)")
            
        } else if credential is ASAuthorizationAppleIDCredential {
            let appleIdCredential = credential as! ASAuthorizationAppleIDCredential
            let userIdentifier = appleIdCredential.user
            let fullName = appleIdCredential.fullName
            let email = appleIdCredential.email ?? "email"
            let authorizationCode = appleIdCredential.authorizationCode
            let authorizationCodeStr = String(decoding: authorizationCode!, as: UTF8.self)
            let identityToken = appleIdCredential.identityToken
            let identityTokenStr = String(decoding: identityToken!, as: UTF8.self)
            let realUserStatus = appleIdCredential.realUserStatus
            printLog("authorizationCodeStr: \(authorizationCodeStr)")
            
        }
    }
    
    func authorizationController(controller: ASAuthorizationController, didCompleteWithError error: Error) {
        printLog("FAILED: \(error.localizedDescription)")
    }
    
    func presentationAnchor(for controller: ASAuthorizationController) -> ASPresentationAnchor {
        return  UIApplication.shared.yhKeyWindow()!
    }
}
    
