//
//  YHLoginMethodManager.swift
//  galaxy
//
//  Created by edy on 2024/5/27.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import AVFoundation

class YHLoginMethodManager {
    
    static let shared = YHLoginMethodManager()
}

extension YHLoginMethodManager {
    
    func autoLogin() {
        YHLoginMethodManager.shared.checkIsSupportAutoLogin {
            support in
            if !support {
                YHHUD.flash(message: "不支持一键登录")
                // 跳转APP自定义登录界面
                let vc = UINavigationController(rootVC: YHOtherLoginViewController())
                vc.modalPresentationStyle = .fullScreen
                UIViewController.current?.present(vc, animated: true)
                return
            }
            // 支持一键登录
            YHLoginMethodManager.shared.enterAutoLoginPage()
        }
    }
    
    func getSDKVersion() -> String {
        return TXCommonHandler.sharedInstance().getVersion()
    }
    
    func configAutoLogin() {
        TXCommonHandler.sharedInstance().setAuthSDKInfo(YhConstant.Alipay.kAliLoginSecretKey) {
            dict in
            printLog(dict)
        }
    }
    
    func checkIsSupportAutoLogin(_ support:((Bool)->())?) {
        // 检测当前环境是否支持一键登录
        TXCommonHandler.sharedInstance().checkEnvAvailable(with: .loginToken) {
            dict in
            
            if let resultCode = dict?["resultCode"] as? String, resultCode == PNSCodeSuccess {
                support?(true)
            } else {
                support?(false)
            }
        }
    }
    
    func enterAutoLoginPage() {
        
        // 3. 开始一键登录流程
        // 3.1 调用加速授权页弹起接口，提前获取必要参数，为后面弹起授权页加速
        
        TXCommonHandler.sharedInstance().accelerateLoginPage(withTimeout: 10.0) {
            dic in
            
            guard let code = dic["resultCode"] as? String else {
                YHHUD.flash(message: "取号，加速授权页弹起失败")
                return
            }
            
            if code != PNSCodeSuccess {
                YHHUD.flash(message: "取号，加速授权页弹起失败")
                return
            }
            
            //3.2 调用获取登录Token接口，可以立马弹起授权页，model的创建需要放在主线程
            let model = self.createLoginUIModel()
            TXCommonHandler.sharedInstance().getLoginToken(withTimeout: 10.0, controller: UIViewController.current!, model: model) {
                dict in
                
                guard let code = dict["resultCode"] as? String else {
                    printLog(dict)
                    return
                }
                
                if code == PNSCodeSuccess {
                    // 点击登录按钮获取登录Token成功回调
                    let token = dict["token"] as? String
                    
                    // 下面用Token去服务器换手机号，此处仅做参考
                    /*
                     
                     [PNSVerifyTopRequest requestLoginWithToken:token complete:^(BOOL isSuccess, NSString * _Nonnull msg, NSDictionary * _Nonnull data) {
                                     NSString *popCode = [data objectForKey:@"code"];
                                     NSDictionary *module = [data objectForKey:@"module"];
                                     NSString *mobile = module[@"mobile"];
                                     if ([popCode isEqualToString:@"OK"] && mobile.length > 0) {
                                         [ProgressHUD showSuccess:@"一键登录成功"];
                                     } else {
                                         [ProgressHUD showSuccess:@"一键登录失败"];
                                     }
                                     dispatch_async(dispatch_get_main_queue(), ^{
                                         [[TXCommonHandler sharedInstance] cancelLoginVCAnimated:YES complete:nil];
                                     });
                                     [weakSelf showResult:data];
                                 }];
                     
                     */
                    
                    return
                }
                
                // 以下是处理一键登录异常
                
                if code == PNSCodeLoginControllerPresentSuccess {
                    printLog("弹起授权页成功")
                    
                } else if code == PNSCodeLoginControllerClickCancel {
                    printLog("点击了授权页的返回")
                    
                } else if code == PNSCodeLoginControllerClickChangeBtn {
                    printLog("点击切换其他登录方式按钮")
                    
                } else if code == PNSCodeLoginControllerClickLoginBtn {
                    
                    if let isChecked = dict["isChecked"] as? Bool, isChecked == true {
                        printLog("点击了登录按钮，check box选中，SDK内部接着会去获取登录Token")
                    } else {
                        printLog("点击了登录按钮，check box未选中，SDK内部不会去获取登录Token")
                    }
                    
                } else if code == PNSCodeLoginControllerClickCheckBoxBtn {
                    printLog("点击了check box")
                    
                } else if code == PNSCodeLoginControllerClickProtocol {
                    printLog("点击了协议富文本")
                    
                } else {
                    printLog("获取登录Token失败")
                }
            }
        }
      
            
    }
    
    func createLoginUIModel() -> TXCustomModel {
        
        let model = TXCustomModel()
        model.navIsHidden = true
        model.sloganIsHidden = true
        model.logoIsHidden = true
        model.changeBtnIsHidden = true
        // 配置二次弹窗
        model.privacyAlertIsNeedShow = true
        
        // 协议勾选框UI自定义
        let uncheckedImg = UIImage(named: "login_privacy_disagree_white")!
        let checkedImg = UIImage(named: "login_privacy_agree_white")!
        model.checkBoxImages = [uncheckedImg, checkedImg]
        model.checkBoxWH = 18.0
        model.checkBoxImageEdgeInsets = UIEdgeInsets(top: 3, left: 3, bottom: 3, right: 3)
        
        model.privacyFont = .PFSC_R(ofSize: 12)
        model.privacyOperatorPreText = "《"
        model.privacyOperatorSufText = "》"
        model.privacyOne = ["《隐私协议》", YHBaseUrlManager.shared.curPrivacyAgreementUrl()]
        model.privacyTwo = ["《用户条款》", YHBaseUrlManager.shared.curUserItemsUrl()]
        
        let privacyUnclickColor = UIColor(red: 1, green: 1, blue: 1, alpha: 0.7)
        let privacyClickColor = UIColor.white
        model.privacyColors = [privacyUnclickColor, privacyClickColor]
        model.privacyFrameBlock = {
            screenSize, superViewSize, frame in
            return CGRectMake(24, KScreenHeight-40-40, superViewSize.width-48, 40)
        }
        
        model.loginBtnFrameBlock = {
            screenSize, superViewSize, frame in
            return CGRectMake(24, KScreenHeight-40-40-30-48, superViewSize.width-48, 48)
        }
        
        // 手机号码UI自定义
        model.numberColor = .white
        model.numberFont = UIFont(name: "DINAlternate-Bold", size: 30)!
        model.numberFrameBlock = {
            screenSize, superViewSize, frame in
            return CGRectMake(frame.minX, KScreenHeight-40-40-30-20-48-35, frame.width, 35)
        }
        
        // 登录按钮自定义UI
        model.loginBtnText = NSAttributedString(string: "本机号码一键登录", attributes: [NSAttributedString.Key.foregroundColor : UIColor.init(hex: 0x121A26), NSAttributedString.Key.font: UIFont.PFSC_M(ofSize: 16)])
        
        let enableLoginBgImg = TXCommonUtils.image(with: .white, size: CGSize(width: KScreenWidth-20*2, height: 48), isRoundedCorner: true, radius: kCornerRadius3)!
        let disableLoginBgImg = TXCommonUtils.image(with: .white.withAlphaComponent(0.4), size: CGSize(width: KScreenWidth-20*2, height: 48), isRoundedCorner: true, radius: kCornerRadius3)!
        let imgArr:[UIImage] = [enableLoginBgImg, disableLoginBgImg, enableLoginBgImg]
        model.loginBtnBgImgs = imgArr
        
        // 创建视频底图View
        let videoBgView = YHAutoLoginView(frame: UIScreen.main.bounds)
        videoBgView.closeBlock = {
            TXCommonHandler.sharedInstance().cancelLoginVC(animated: true)
        }
        // 改变登录方式
        videoBgView.changeLoginBlock = {
            let vc = YHOtherLoginViewController()
            UIViewController.current?.navigationController?.pushViewController(vc, animated:true)
        }
        model.customViewBlock = {
            superCustomView in
                superCustomView.insertSubview(videoBgView, at: 0)
        }
        model.customViewLayoutBlock = {
            screenSize, contentViewFrame, navFrame, titleBarFrame, logoFrame, sloganFrame, numberFrame, loginFrame, changeBtnFrame, privacyFrame in
               
                videoBgView.frame = UIScreen.main.bounds
        }
        
        if model.privacyAlertIsNeedShow == false {
            return model
        }
        
        // 配置二次弹窗
        model.privacyAlertIsNeedShow = true
        model.privacyAlertMaskAlpha = 0.5;
        model.privacyAlertMaskColor = .black
        model.privacyAlertCornerRadiusArray = [3, 3, 3, 3]
        model.privacyAlertBackgroundColor = .white
        model.privacyAlertAlpha = 1.0
        model.privacyAlertTitleBackgroundColor = .white
        model.privacyAlertContentBackgroundColor = .white
        model.privacyAlertTitleFont = .PFSC_R(ofSize: 16)
        model.privacyAlertTitleColor = UIColor.black
        model.privacyAlertContentColors = [UIColor.gray, UIColor.orange]
        model.privacyAlertContentAlignment = .center
        model.privacyAlertContentColors = [.black, .brandMainColor]
        
        let activeImage = TXCommonUtils.image(with: .brandMainColor, size: CGSizeMake(UIScreen.main.bounds.size.width - 2 * 18, 45), isRoundedCorner: true, radius: 6)!
        let hightLightImage = TXCommonUtils.image(with: .brandMainColor, size: CGSizeMake(UIScreen.main.bounds.size.width - 2 * 18, 45), isRoundedCorner: true, radius: 6)!
        model.privacyAlertBtnBackgroundImages = [activeImage, hightLightImage]
        
        model.privacyAlertButtonTextColors = [UIColor.white, UIColor.white]
        model.privacyAlertButtonFont = .PFSC_R(ofSize: 16)
        model.privacyAlertCloseButtonIsNeedShow = true
        model.privacyAlertMaskIsNeedShow = true
        model.privacyAlertIsNeedAutoLogin = true
        model.tapPrivacyAlertMaskCloseAlert = false
        model.expandAuthPageCheckedScope = true
        model.privacyAlertCloseButtonIsNeedShow = true
        model.privacyAlertTitleFrameBlock = {
            screenSize, superViewSize, frame in
            return CGRectMake(0, 20, frame.size.width, 22)
        }
        model.privacyAlertPrivacyContentFrameBlock = {
            screenSize, superViewSize, frame in
            return CGRectMake(0, 20+22+20, frame.size.width-20, frame.size.height);
        }
        model.privacyAlertButtonFrameBlock = {
            screenSize, superViewSize, frame in
            return CGRectMake(frame.origin.x, superViewSize.height - 50 - 20, frame.size.width, 45)
        }
        model.privacyAlertFrameBlock = {
            screenSize, superViewSize, frame in
            return CGRectMake(40, (superViewSize.height - 150)/2.0, screenSize.width-80, 200)
        }
        return model
    }
}


