//
//  YHCodeSueecssWithVideoBkgViewController.swift
//  galaxy
//
//  Created by davidhuangA on 2024/5/19.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import IQKeyboardManagerSwift
import AVFoundation


class YHCodeSueecssWithVideoBkgViewController: YHBaseViewController {
    
    var time = 60
    
    var bgImageView: UIImageView!
    var closeButton: UIButton!
    var loginTitleLabel: UILabel!
    var loginSubTitleLabel: UILabel!
    var getCodeLabel: UILabel!
    var getCodeButton: UIButton!
    var smscodeView: YHSmsCodeInputView!
    var phoneNumber: String?
    var viewModel: YHLoginViewModel?
    
    private var isRequestFlag : Bool = false
    
    override func viewDidLoad() {
        super.viewDidLoad()
        setView()
        startTime()
    }
    
    override func viewDidAppear(_ animated: Bool) {
        super.viewDidAppear(animated)
        smscodeView.textField.becomeFirstResponder()
    }
    
    //视频
    private var player: AVPlayer?
    private var playerLayer: AVPlayerLayer?
    
    lazy var frontHoldView: UIView = {
        let view = UIView()
        view.backgroundColor = UIColor.mainTextColor30
        return view
    }()
    
    
    override var preferredStatusBarStyle: UIStatusBarStyle {
        return .lightContent
    }
    
    override func viewDidDisappear(_ animated: Bool) {
        super.viewDidDisappear(animated)
        isRequestFlag = false
    }
}


extension YHCodeSueecssWithVideoBkgViewController {
    private func setupBackgroundVideo() {
        guard let videoURL = Bundle.main.url(forResource: "loginBkg", withExtension: "mov") else { return }
        player = AVPlayer(url: videoURL)
        player?.actionAtItemEnd = .none
        playerLayer = AVPlayerLayer(player: player)
        playerLayer?.frame = view.bounds
        playerLayer?.videoGravity = .resizeAspectFill
        view.layer.insertSublayer(playerLayer!, at: 0)
        player?.play()
        player?.seek(to: .zero)
        
        
        NotificationCenter.default.addObserver(self, selector: #selector(playerItemDidPlayToEndTimeNotification), name: AVPlayerItem.didPlayToEndTimeNotification, object: nil)
    }
    
    @objc func playerItemDidPlayToEndTimeNotification() {
        player?.seek(to: .zero)
    }
}


extension YHCodeSueecssWithVideoBkgViewController {
    func setView() {
        viewModel = YHLoginViewModel()
        gk_navBackgroundColor = .clear
        gk_navShadowColor = .clear
        gk_navigationBar.isHidden = true
        
        view.backgroundColor = .white
        
        setupBackgroundVideo()
        setupFrontUI()
    }
    
    func requetLogin(phone: String, code: String) {
        if isRequestFlag {
#if DEBUG
            YHHUD.flash(message: "请求已发送")
#endif
            return
        }
        
        isRequestFlag = true
        YHHUD.show(.progress(message: "登录中..."))
        self.viewModel?.login(phone : phone, code: code, callBackBlock: {[weak self] success,error in
            YHHUD.hide()
            self?.isRequestFlag = false
            guard let self = self else { return }
            if success == false {
                
                if error?.errorCode == YHErrorCode.unregisterError.rawValue {
                    YHCommonAlertView.show("状态提示", "您的账号已注销，暂时无法登录app \n \r\n具体详情可邮件联系\r\nnick.gzm@galaxyoversea.com", "", "我知道了") {
                        self.navigationController?.popViewController()
                    }
                } else {
                    self.smscodeView.textField.becomeFirstResponder()
                    YHHUD.flash(message: error?.errorMsg ?? "")
                }
            } else {
                YHLoginManager.shared.loginSuccessActionBlock?()
                YHHUD.flash(message: "登录成功")
                IQKeyboardManager.shared.enable = true
                self.dismiss(animated: true)
            }
        })
    }
    
    func startTime() {
        getCodeLabel.isHidden = false
        getCodeButton.isHidden = true
        let sourceTimer = DispatchSource.makeTimerSource()
        sourceTimer.schedule(deadline: DispatchTime.now(), repeating: DispatchTimeInterval.milliseconds(1000), leeway: DispatchTimeInterval.milliseconds(0))
        sourceTimer.setEventHandler {
            if self.time != 0 {
                self.time -= 1
                DispatchQueue.main.async {
                    self.getCodeLabel?.text = String.localizedStringWithFormat("重新获取（%d）",self.time)
                }
            } else if self.time <= 0 {
                sourceTimer.cancel()
                DispatchQueue.main.async {
                    self.time = 60
                    self.getCodeLabel.isHidden = true
                    self.getCodeButton.isHidden = false
                }
            }
        }
        // 启动定时器
        sourceTimer.resume()
    }
    
    @objc func startClicked() {
        YHHUD.show(.progress(message: ""))
        viewModel?.getLoginCode(phoneNumber ?? "", callBackBlock: {[weak self] success,error in
            YHHUD.hide()
            
            guard let self = self else { return }
            if success == true {
                self.startTime()
            } else {
                YHHUD.flash(message: error?.errorMsg ?? "")
            }
        })
    }
    
    @objc func close() {
        IQKeyboardManager.shared.enable = false
        self.navigationController?.popViewController()
    }
    func setupFrontUI() {
        //        bgImageView = {
        //            let imageView = UIImageView()
        //            imageView.image = UIImage(named: "login_phone_bg_image")
        //            imageView.isUserInteractionEnabled = true
        //            return imageView
        //        }()
        //        view.addSubview(bgImageView)
        //        bgImageView.snp.makeConstraints { make in
        //            make.left.right.top.equalTo(view)
        //            make.height.equalTo(300)
        //        }
        
        view.addSubview(frontHoldView)
        frontHoldView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
        
        closeButton = {
            let button = UIButton(type: .custom)
            //            button.setImage(UIImage(named: "login_back"), for: .normal)
            button.setImage(UIImage(named: "back_icon_for_code_input"), for: .normal)
            button.addTarget(self, action: #selector(close), for: .touchUpInside)
            return button
        }()
        frontHoldView.addSubview(closeButton)
        closeButton.snp.makeConstraints { make in
            make.left.equalTo(13)
            make.top.equalTo(51)
            make.width.height.equalTo(30)
        }
        
        loginTitleLabel = {
            let label = UILabel()
            label.text = "请输入验证码"
            label.font = UIFont.PFSC_B(ofSize: 30)
            label.textColor = UIColor.white
            return label
        }()
        frontHoldView.addSubview(loginTitleLabel)
        loginTitleLabel.snp.makeConstraints { make in
            make.left.equalTo(24)
            make.right.equalTo(-24)
            make.top.equalTo(closeButton.snp.bottom).offset(67)
            make.height.equalTo(42)
        }
        
        loginSubTitleLabel = {
            let label = UILabel()
            label.text = "已发送至 \(phoneNumber ?? "")"
            label.font = UIFont.PFSC_R(ofSize: 15)
            label.textColor =  UIColor(hex: 0xffffff, alpha: 0.8)
            return label
        }()
        frontHoldView.addSubview(loginSubTitleLabel)
        loginSubTitleLabel.snp.makeConstraints { make in
            make.left.equalTo(24)
            make.right.equalTo(-24)
            make.top.equalTo(loginTitleLabel.snp.bottom).offset(4)
            make.height.equalTo(20)
        }
        
        smscodeView = {
            let view = YHSmsCodeInputView(config: YHSmsCodeViewConfig())
            view.complete = { [weak self] code in
                guard let self = self else { return }
                
                if let phone = self.phoneNumber {
                    // 登录接口需要加一个deviceToken参数
                    YHHUD.show(.progress(message: "登录中..."))
                    if YHLoginManager.shared.deviceTokenModel.registerId.isEmpty {
                        JPUSHService.registrationIDCompletionHandler {
                            resCode, registrationID in
                            YHHUD.hide()
                            YHLoginManager.shared.deviceTokenModel.registerId = registrationID ?? ""
                            self.requetLogin(phone: phone, code: code)
                        }
                    } else {
                        self.requetLogin(phone: phone, code: code)
                    }
                    
                } else {
                    printLog("errror :  电话号码为空")
                }
            }
            return view
        }()
        frontHoldView.addSubview(smscodeView)
        smscodeView.snp.makeConstraints { make in
            make.left.right.equalToSuperview()
            make.top.equalTo(288)
            make.height.equalTo(55)
        }
        
        getCodeLabel = {
            let button = UILabel()
            button.font = UIFont.PFSC_M(ofSize: 16)
            button.text = "重新发送（58）"
            button.textColor = UIColor.mainTextColor
            button.textAlignment = .center
            button.isHidden = false
            button.layer.cornerRadius = 24
            button.backgroundColor = UIColor.init(hex: 0xffffff,transparency: 0.4)
            button.clipsToBounds = true
            //            button.layer.borderWidth = 1
            //            button.layer.borderColor = UIColor(hex: 0xebeef4).cgColor
            return button
        }()
        frontHoldView.addSubview(getCodeLabel)
        getCodeLabel.snp.makeConstraints { make in
            make.centerX.equalToSuperview()
            make.top.equalTo(382)
            make.height.equalTo(48)
            make.width.equalTo(335)
        }
        
        getCodeButton = {
            let button = UIButton(type: .custom)
            button.titleLabel?.font = UIFont.PFSC_M(ofSize: 16)
            button.contentHorizontalAlignment = .center
            button.setTitle("获取验证码", for: .normal)
            button.setTitleColor( UIColor(hex: 0x000000, alpha: 1.0), for: .normal)
            button.addTarget(self, action: #selector(startClicked), for: .touchUpInside)
            button.isHidden = true
            button.layer.cornerRadius = 24
            button.clipsToBounds = true
            button.backgroundColor = UIColor(hex: 0xffffff, alpha: 1.0)
            //            button.layer.borderWidth = 1
            //            button.layer.borderColor = UIColor(hex: 0xebeef4).cgColor
            return button
        }()
        frontHoldView.addSubview(getCodeButton)
        getCodeButton.snp.makeConstraints { make in
            make.centerX.equalToSuperview()
            make.top.equalTo(382)
            make.height.equalTo(48)
            make.width.equalTo(335)
        }
        
        
        let tap = UITapGestureRecognizer(target: self, action: #selector(clickFrontView))
        frontHoldView.addGestureRecognizer(tap)
    }
    
    @objc func clickFrontView() {
        self.smscodeView.textField.becomeFirstResponder()
    }
}
